"""Module setting global parameters for the application such as cache, route generation, etc."""

import os
from pathlib import Path
from typing import List, Literal, Tuple


LOCATION_PREFIX = Path('src')
PARAMETERS_DIR = LOCATION_PREFIX / 'parameters'
AMENITY_SELECTORS_PATH = PARAMETERS_DIR / 'amenity_selectors.yaml'
LANDMARK_PARAMETERS_PATH = PARAMETERS_DIR / 'landmark_parameters.yaml'
OPTIMIZER_PARAMETERS_PATH = PARAMETERS_DIR / 'optimizer_parameters.yaml'


PAYPAL_CLIENT_ID = 0 # os.getenv("your-paypal-client-id")
PAYPAL_SECRET = 0 # os.getenv("your-paypal-secret")
PAYPAL_API_URL = 0 # "https://api-m.sandbox.paypal.com"

SUPABASE_URL = os.environ["SUPABASE_URL"]
SUPABASE_KEY = os.environ["SUPABASE_API_KEY"]
SUPABASE_TEST_USER_ID = os.environ["SUPABASE_TEST_USER_ID"]


cache_dir_string = os.getenv('OSM_CACHE_DIR', './cache')
OSM_CACHE_DIR = Path(cache_dir_string)

OSM_TYPES = List[Literal['way', 'node', 'relation']]
BBOX = Tuple[float, float, float, float]

MEMCACHED_HOST_PATH = os.getenv('MEMCACHED_HOST_PATH', None)
if MEMCACHED_HOST_PATH == "none":
    MEMCACHED_HOST_PATH = None
